unit Onix32;

interface

const

        { These are the various modes that one can use for indexing. }
RecordMode                      = 1;
WordMode                        = 2;
IDFMode                         = 3;

        { These are the various settings one can use for creating an index. }
ixSetSinglePointIndex	 		= 1;
ixSetDistributedIndex	 		= 2;
ixSetVariableLengthRecordInfo 	= 3;
ixSetFixedLengthRecordInfo 		= 4;
ixSet32BitRecordInfoOffset 		= 5;
ixSet64BitRecordInfoOffset 		= 6;
ixSetFixedLengthRecordID		= 7;
ixSetVariableLengthRecordID 	= 8;
ixSetRecordID32BitOffset 		= 9;
ixSetRecordID64BitOffset 		= 10;
ixSetIndexMode 				    = 11;
ixSetIndexFileName			    = 12;
ixSetRankingMethodOne			= 13;
ixSetRankingMethodTwo			= 14;


        { Various error and Status Codes. }

AllDataOptimizedAway 	        = 6;   { After running the optomizer, there is no data left }
Done				            = 5;   { We are done with whatever we are doing}
Full				            = 4;   { Whatever you have been working with is full. }
Found				            = 3;   { What you were looking for has been found. }
NotFound			            = 2;   { What you were looking for was not found. }
EndOfHitList			        = 1;   { We are at the end of the query vector. }
eNoError  	      		        = 0;   { NoError }
eNoMemory         		        = -1;  { Not enough memory. }
eReadOnly         		        = -2;  { File is read only. }
eReading          		        = -3;  { Error reading from file. }
eWriting          		        = -4;  { Error writing to file }
eSeeking          		        = -5;  { We were not able to seek where we wanted }
eFileNotFound     		        = -6;  { Not able to find the file }
eNoDrive          		        = -7;  { No such drive }
eAccess           		        = -8;  { File is locked by another process }
eFileExists       		        = -9;  { File already exists }
eCantDeleteFile   		        = -10; { For some reason the file can't be deleted  }
eOpeningFile			        = -11; { Can't open the file specified }
eClosingFile			        = -12; { Can't close the file specified }
eMagicNumberMismatch 	        = -13; { File is not index file or is corrupt }
eIndexLocked       		        = -14; { Index is locked by another process  }
eNoCurrentKey		 	        = -15; { No current key (Need to find a key first.) }
eEndOfWordList		 	        = -16; { End of the wordlist  }
eIndexNotLoaded	 		        = -17; { The index isn't loaded   }
eNoCurrentHit		 	        = -19; { There isn't a current hit.  (Probably no hits were returned.) }
eMalformedParameter 		    = -20; { The parameter in the expression   }
eMalformedExpression 	        = -21; { Something is wrong with the query expression   }
eMismatchedQuotes		        = -22; { There are mismatched quotes in the query expression  }
eMismatchedParens 		        = -23; { There are mismatched parens () in the query.  }
eLeftParenExpected 		        = -24; { There is a extra right paren in the query expression  }
eRightParenExpected 		    = -25; { There is an extra left paren in the query expression }
eTermExpectedInRange 	        = -26; { You need a term on both sides of a range (i.e., X - Y) }
eLeftAngleBracketExpected 	    = -27; { A left angle bracket \"<\" is expected in the query expression.  Check the usage of the angle brackets within the query expression. }
eRightAngleBracketExpected 	    = -28; { A right angle bracket \">\" is expected in the query expression.  Check the usage of the angle brackets within the query expression. }
eCantHaveOperatorsInsideQuotes 	= -29; { The only operators allowed inside a quote are: Or, Left Parentheses and Right Parentheses -- |,(,)") }
eRightHandQuoteExpected 	    = -30; { Missing a right hand quote in the query expression }
eMalformedQueryTerm 		    = -31; { The Query Term must be a hex number i.e, 0xffaa  }
eNoDataInIndex			        = -32; { We have an empty index }
eNoRetrievalSession		        = -33; { We need to start a retrieval session before querying the index }
eNoIndexSession			        = -34; { We need to start an index session before starting to index. }
eCompressionError		        = -35; { General compression error. (i.e., didn't start or end correctly }
eNumberOutOfRange		        = -36; { The value specified is not in an acceptable range. }
eGeneralError      		        = -37; { Beats me what the error is.  }
eNoDataStoredInIndex		    = -38; { There was a request for record data but none was present in the index.  }
eLibraryTimedOut		        = -39; { This library has timed out.  Contact Art Pollard (pollarda@lextek.com) to get details. }
eIndexIsOnRemoveableDisk	    = -40; { Your license doesn't allow for the index to be on a removeable disk. }
eMaxDataIndexed			        = -41; { Your license doesn't allow for more data to be indexed.  (Too much data indexed for license.)  }
eInvalidPasscode		        = -42; { An invalid license passcode was entered.  Recheck passcode or contact Lextek International (http://www.lextek.com) for a valid passcode.  }
eHitNotFound                    = -43; { The hit searched for is not in this query vector  }
eDeletingFile			        = -44; { Sorry, can't delete the file. }
eInvalidKeyLength		        = -45; { The key length does not conform to the specifications.  (Probably too long) }
ePartitionNotFound		        = -46; { The index partition specified was not found. }
eErrorInRecordIDCount		    = -47; { There are either too few or too many record IDs stored for the number of records indexed. }
eErrorInRecordInfoCount		    = -48; { There are either too few or too many record infos stored for the number of records indexed. }


type

BooleanT = (BooleanTrue = 1, BooleanFalse = 0);


        { This is the structure that is used to pass the word information in during indexing. }
WordTypeT = record
      TheWord:Array[0..255] of Char;
      Length:Char;
      TermType:Char;
      FileNumber:LongInt;
      RecordNumber:LongInt;
      RecordOffset:LongInt;
      LastWordNumber:LongInt;
end;

        { This is the cursor structure used to navigate the wordlist. }
DictionaryCursorT = record
	HasCurrentWord:Integer;
	TheWord:Array[0..255] of Char;
	NumberOfRecords:LongInt;
	NumberOfWords:LongInt;
end;

OnixDataCursorT = record
        N:LongInt;
        RecordNumber:LongInt;
        DataOffset:LongInt;
        DataLength:LongInt;
        CurrentPos:LongInt;
        Done:BooleanT;
end;




        { Create and dispose of the index manager }
function ixCreateIndexManager(Passcode1:LongInt; Passcode2:LongInt; var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixCreateIndexManager';
procedure ixDeleteIndexManager(IndexManager:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixDeleteIndexManager';

        { Creating indexes }
function ixCreateIndexCreationParams(var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixCreateIndexCreationParams';
procedure ixDeleteIndexCreationParams(Params:Pointer);
	stdcall; external 'Onix32.dll' name '_ixDeleteIndexCreationParams';
procedure ixResetIndexCreationParams(Params:Pointer);
	stdcall; external 'Onix32.dll' name '_ixResetIndexCreationParams';
procedure ixSetIndexCreationParams(Params:Pointer; Parameter:LongInt;  ParameterValue:Pointer);
	stdcall; external 'Onix32.dll' name '_ixSetIndexCreationParams';
procedure ixCreateIndex(IndexManager:Pointer; FileSpec:PChar; IndexMode:Integer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixCreateIndex';
procedure ixCreateIndexEx(IndexManager:Pointer; Params:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixCreateIndexEx';

        { Get and set the location of temporary files and get their sizes. }
procedure ixSetLocationForTemporaryFiles(PathName:PChar);
	stdcall; external 'Onix32.dll' name '_ixSetLocationForTemporaryFiles';
procedure ixGetLocationForTemporaryFiles(PathName:PChar);
	stdcall; external 'Onix32.dll' name '_ixGetLocationForTemporaryFiles';
procedure ixGetTempDiskSpaceUsage(Indexer:Pointer; var TempFileLength:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixGetTempDiskSpaceUsage';

        { Opening and closing indexes. }
procedure ixOpenIndex(IndexManager:Pointer; FileSpec:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixOpenIndex';
procedure ixCloseIndex(IndexManager:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixCloseIndex';
procedure ixReloadIndex(IndexManager:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixReloadIndex';

        { Routines for indexing }
procedure ixIncrementRecord(IndexingEngine:Pointer; var Word:WordTypeT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixIncrementRecord';
procedure ixIndexWord(IndexingEngine:Pointer; var Word:WordTypeT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixIndexWord';
procedure ixIndexWordSpecial(IndexingEngine:Pointer; var Word:WordTypeT; Flags:LongInt; Param:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixIndexWordSpecial';
procedure ixStartField(IndexingEngine:Pointer; FieldName:PChar; FieldNameLength:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixStartField';
procedure ixEndField(IndexingEngine:Pointer; FieldName:PChar; FieldNameLength:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixEndField';
procedure ixStemEnglishWord(StemmedWord:PChar; Word:PChar);
	stdcall; external 'Onix32.dll' name '_ixStemEnglishWord';
function ixStartIndexingSession(IndexManager:Pointer; var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixStartIndexingSession';
procedure ixEndIndexingSession(IndexManager:Pointer; IndexingEngine:Pointer; var Word:WordTypeT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixEndIndexingSession';
procedure ixFinalProcessIndex(IndexManager:Pointer; Indexer:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixFinalProcessIndex';
procedure ixMakeIndexActive(IndexManager:Pointer; Indexer:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixMakeIndexActive';
procedure ixSetFinalIndexDataPosition(Indexer:Pointer; FileName:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixSetFinalIndexDataPosition';

        { Additional Routines for performing distributed indexing. }
function ixStartDistributedIndexingSession(Options:Pointer; var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixStartDistributedIndexingSession';
procedure ixEndDistributedIndexingSession(Indexer:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixEndDistributedIndexingSession';
procedure ixAppendDistributedDataToIndex(IndexManager:Pointer; FileName:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixAppendDistributedDataToIndex';


        { Routines for storing and retrieving an arbitrary piece of data }
        { that is associated with every record.... }
procedure ixStoreRecordData(IndexingEngine:PChar; DataBuff:PChar; RecDataSize:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixStoreRecordData';
procedure ixStoreMoreRecordData(IndexingEngine:Pointer; DataBuff:PChar; RecDataSize:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixStoreMoreRecordData';
procedure ixRetrieveRecordData(IndexManager:Pointer; DataBuff:PChar; DataBuffSize:LongInt; var ReturnedDataSize:LongInt; RecordNum:LongInt; var DataCursor:OnixDataCursorT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixRetrieveRecordData';
procedure ixRetrieveMoreRecordData(IndexManager:Pointer; DataBuff:PChar; DataBuffSize:LongInt;  var ReturnedDataSize:LongInt; var DataCursor:OnixDataCursorT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixRetrieveMoreRecordData';

        { Functions for managing record IDs. }
procedure ixProcessRecordID(IndexingEngine:Pointer; RecordID:PChar; RecordIDLength:LongInt; StoreRecordID:BooleanT; IndexRecordID:BooleanT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixProcessRecordID';
procedure ixRetrieveRecordID(IndexManager:Pointer; Buff:PChar; BuffSize:LongInt; var ReturnedIDSize:LongInt; HexRecordID:PChar; RecordNum:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixRetrieveRecordID';
procedure ixFindRecordID(IndexManager:Pointer; RecordIDName:PChar;  var RecordNum:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixFindRecordID';

        { Functions to manage the partitions in a multifile index..... }
procedure ixChangePartitionLocation(var PartitionNumber:LongInt; NewPosition:PChar; OldPosition:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixChangePartitionLocation';
procedure ixWritePartitionLocation(PartitionNumber:LongInt; FileName:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixWritePartitionLocation';

        { Functions to help give statistics about the index. }
procedure ixNumberOfRecordsInIndex(IndexManager:Pointer; var NumRecords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixNumberOfRecordsInIndex';
procedure ixHighestRecordNumberInIndex(IndexManager:Pointer; var HighestRecord:LongInt;  var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixHighestRecordNumberInIndex';
function ixGetNumberOfUnoptimizedInsertions(IndexManager:Pointer): Integer;
	stdcall; external 'Onix32.dll' name '_ixGetNumberOfUnoptimizedInsertions';

        { Routines for managing the deletions of records }
function ixIsRecordDeleted(IndexManager:Pointer; RecordNum:LongInt; var StatusCode:LongInt): BooleanT;
	stdcall; external 'Onix32.dll' name '_ixIsRecordDeleted';
procedure ixDeleteRecordNum(IndexManager:Pointer; RecordNum:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixDeleteRecordNum';
procedure ixDeleteRecordNums(IndexManager:Pointer; var RecordNumArray:LongInt; NumRecords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixDeleteRecordNums';
procedure ixUnDeleteRecordNum(IndexManager:Pointer; RecordNum:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixUnDeleteRecordNum';
procedure ixUnDeleteRecordNums(IndexManager:Pointer; var RecordNumArray:LongInt; NumRecords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixUnDeleteRecordNums';
procedure ixOutputDeletedRecords(IndexManager:Pointer; var RecordNumArray:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixOutputDeletedRecords';
function ixGetNumberOfRecordsDeleted(IndexManager:Pointer; var StatusCode:LongInt):LongInt;
	stdcall; external 'Onix32.dll' name '_ixGetNumberOfRecordsDeleted';

        { Routines for the processing of standard queries }
procedure ixStartRetrievalSession(IndexManager:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixStartRetrievalSession';
procedure ixEndRetrievalSession(IndexManager:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixEndRetrievalSession';
procedure ixConvertQuery(TextQuery:PChar; HexQuery:PChar);
	stdcall; external 'Onix32.dll' name '_ixConvertQuery';
procedure ixConvertQuery2(HexQuery:PChar; TextQuery:PChar);
	stdcall; external 'Onix32.dll' name '_ixConvertQuery2';
procedure ixLongQueryFormToShortQueryForm(Query:PChar; Proximity:LongInt);
	stdcall; external 'Onix32.dll' name '_ixLongQueryFormToShortQueryForm';
procedure ixCharToHex(C:Char; Output:PChar);
	stdcall; external 'Onix32.dll' name '_ixCharToHex';
procedure ixHexToChar(Char:PChar; Hex:PChar);
	stdcall; external 'Onix32.dll' name '_ixHexToChar';
procedure ixCharWordToHexWord(HexWord:PChar; CharWord:PChar; Length:LongInt);
	stdcall; external 'Onix32.dll' name '_ixCharWordToHexWord';

function
ixProcessQuery(IndexManager:Pointer; RankedQueryString:PChar; QueryString:PChar; var StatusCode:LongInt):Pointer;
	stdcall; external 'Onix32.dll' name '_ixProcessQuery';
procedure
ixNumHits(Vector:Pointer; var NumHits:LongInt; var NumRecords:LongInt; var NumWords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixNumHits';

        { Routines for accessing and navigating the wordlist. }
procedure ixFindKey(IndexManager:Pointer; var Cursor:DictionaryCursorT; Word:PChar; var Found:BooleanT; var NumRecords:LongInt; var NumWords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixFindKey';
procedure ixNextKey(IndexManager:Pointer; var Cursor:DictionaryCursorT; Word:PChar; var NumRecords:LongInt; var NumWords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixNextKey';
procedure ixPreviousKey(IndexManager:Pointer; var Cursor:DictionaryCursorT;  Word:PChar; var NumRecords:LongInt; var NumWords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixPreviousKey';
procedure ixCurrentKey(IndexManager:Pointer; var Cursor:DictionaryCursorT; Word:PChar; var NumRecords:LongInt; var NumWords:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixCurrentKey';

        { Routines for manually processing queries }
function ixCreateResultVector(var StatusCode:LongInt):Pointer;
	stdcall; external 'Onix32.dll' name '_ixCreateResultVector';
procedure ixDeleteResultVector(Vector:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixDeleteResultVector';
function ixGetCurrentQueryVector(IndexManager:Pointer;  var Cursor: DictionaryCursorT;  var StatusCode:LongInt):Pointer;
	stdcall; external 'Onix32.dll' name '_ixGetCurrentQueryVector';
function ixVectorAnd(Vector1:Pointer; Vector2:Pointer; var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixVectorAnd';
function ixVectorOr(Vector1:Pointer; Vector2:Pointer; var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixVectorOr';
function ixVectorNot(Vector1:Pointer;  Vector2:Pointer; var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixVectorNot';
procedure ixVectorRewind(Vector:Pointer; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorRewind';
procedure ixVectorCurrentHit(Vector:Pointer; var RecordNum:LongInt; var WordNum:LongInt; var CountNum:LongInt; var Weight:Single; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorCurrentHit';
procedure ixVectorNextHit(Vector:Pointer; var RecordNum:LongInt; var WordNum:LongInt; var Count:LongInt; var Weight:Single; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorNextHit';
procedure ixVectorNextRecord(Vector:Pointer; var RecordNum:LongInt; var WordNum:LongInt; var Count:LongInt; var Weight:Single; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorNextRecord';
procedure ixVectorPreviousHit(Vector:Pointer; var RecordNum:LongInt; var WordNum:LongInt; var Count:LongInt; var Weight:Single; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorPreviousHit';
procedure ixVectorPreviousRecord(Vector:Pointer; var RecordNum:LongInt; var WordNum:LongInt; var Count:LongInt; var Weight:Single; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorPreviousRecord';
function ixGetTermCountVector(var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixGetTermCountVector';

procedure ixVectorAddHit(ResultVector:Pointer; RecordNum:LongInt; WordNum:LongInt; Weight:Single; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixVectorAddHit';

        { Unicode support routines.... }
procedure ucInitializeNormalizationTable(var TableBuffer:ShortInt; MaxChars:LongInt; Lower:BooleanT);
	stdcall; external 'Onix32.dll' name '_ucInitializeNormalizationTable';
procedure ucTableNormalizeChar(var TableBuffer:ShortInt; var UnicodeChar:ShortInt; MaxChars:LongInt);
	stdcall; external 'Onix32.dll' name '_ucTableNormalizeChar';
procedure ucNormalizeChar(var UnicodeChar:ShortInt;  Lower:BooleanT);
	stdcall; external 'Onix32.dll' name '_ucNormalizeChar';
procedure ixUnicodeCharToHex(C:Char; Output:PChar);
	stdcall; external 'Onix32.dll' name '_ixUnicodeCharToHex';
procedure ixUnicodeHexToChar(Char:PChar; Hex:PChar);
	stdcall; external 'Onix32.dll' name '_ixUnicodeHexToChar';

        { Routines to assist in highlighting query terms (Supports wildcards */? with escape \) }
function ixCreateHighlightMatcher(var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixCreateHighlightMatcher';
procedure ixDeleteHighlightMatcher(HighlightMatcher:Pointer);
	stdcall; external 'Onix32.dll' name '_ixDeleteHighlightMatcher';
procedure ixAddWildCardPatternToHighlightMatcher(HighlightMatcher:Pointer; Pattern:PChar; PatternLength:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixAddWildCardPatternToHighlightMatcher';
function ixHighlightMatcherMatch(HighlightMatcher:Pointer; Word:PChar; WordLength:LongInt) : BooleanT;
	stdcall; external 'Onix32.dll' name '_ixHighlightMatcherMatch';

        { Routines to assist web crawlers parse robots.txt }
function ixCreateRobotsTxtParser(var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixCreateRobotsTxtParser';
procedure ixDeleteRobotsTxtParser(Parser:Pointer);
	stdcall; external 'Onix32.dll' name '_ixDeleteRobotsTxtParser';
procedure ixSetRobotName(Parser:Pointer; Name:PChar; CompareLength:LongInt);
	stdcall; external 'Onix32.dll' name '_ixSetRobotName';
procedure ixParseRobotsTxt(Parser:Pointer; RobotsTxt:PChar);
	stdcall; external 'Onix32.dll' name '_ixParseRobotsTxt';
procedure ixOutputCompactRobotsTxt(Parser:Pointer; RobotsTxt:PChar);
	stdcall; external 'Onix32.dll' name '_ixOutputCompactRobotsTxt';
function ixRobotsPermissionGranted(Parser:Pointer; URL:PChar): BooleanT;
	stdcall; external 'Onix32.dll' name '_ixRobotsPermissionGranted';
function ixRobotsPermissionGrantedFullURL(Parser:Pointer; URL:PChar): BooleanT;
	stdcall; external 'Onix32.dll' name '_ixRobotsPermissionGrantedFullURL';
function ixRobotsTxtLength(Parser:Pointer): LongInt;
	stdcall; external 'Onix32.dll' name '_ixRobotsTxtLength';

        { Routines for managing the stop word list }
function ixCreateStopWordList(var StatusCode:LongInt): Pointer;
	stdcall; external 'Onix32.dll' name '_ixCreateStopWordList';
procedure ixDeleteStopWordList(StopWordList:Pointer);
       	stdcall; external 'Onix32.dll' name '_ixDeleteStopWordList';
procedure ixAddStopWord(StopWordList:Pointer; Word:PChar; WordLength:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixAddStopWord';
procedure ixAddStopWordList(StopWordList:Pointer; FileName:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixAddStopWordList';
function ixIsStopWord(StopWordList:Pointer; PrefixLength:LongInt; Word:PChar; WordLength:LongInt): BooleanT;
	stdcall; external 'Onix32.dll' name '_ixIsStopWord';
function ixNumStopWords(StopWordList:Pointer): LongInt;
	stdcall; external 'Onix32.dll' name '_ixNumStopWords';

        { Routines to manage the optimization of the index. }
procedure ixPerformOptimization(IndexManager:Pointer; BigOptimization:BooleanT; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixPerformOptimization';
procedure ixOptimizeIndex(IndexManager:Pointer; OptimizationLevel:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixOptimizeIndex';
procedure ixEndOptimization(IndexManager:Pointer; FileName:PChar; Flags:LongInt; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixEndOptimization';
function ixIndexNeedsLittleOptimization(IndexManager:Pointer; var StatusCode:LongInt): BooleanT;
	stdcall; external 'Onix32.dll' name '_ixIndexNeedsLittleOptimization';
function ixIndexNeedsBigOptimization(IndexManager:Pointer; var StatusCode:LongInt): BooleanT;
	stdcall; external 'Onix32.dll' name '_ixIndexNeedsBigOptimization';

{ Routines to manage the stats file(s) }
procedure ixOutputStatsFile(IndexManager:Pointer; FileName:PChar; var StatusCode:LongInt);
	stdcall; external 'Onix32.dll' name '_ixOutputStatsFile';

{ Used to get the current status message text string (Errors, UnErrors, etc.)  }
{ void GetStatusMessage(StatusCodeT Status, char *StatusMessageBuff); }
function ixGetStatusMessage(var StatusCode:LongInt; StatusMessageBuff:PChar; BuffLength:LongInt): PChar;
	stdcall; external 'Onix32.dll' name '_ixGetStatusMessage';

implementation

end.
