#ifndef __ONIX_API__
#define __ONIX_API__

#include <stdlib.h>
#include "onixtype.h"
#include "platform.h"


//#define __ONIX_WINDOWS_DLL__
//#define __ONIX_MICROSOFT__

#ifdef __ONIX_MACINTOSH__
#define WinStuff
#define FuncType
#endif


#ifdef __ONIX_BORLAND__
#		ifdef __ONIX_WINDOWS_DLL__
#			define FuncType __export
#		endif
#		define WinStuff
#endif

#ifdef __ONIX_MICROSOFT__
#	define FuncType   __stdcall
#	ifdef __ONIX_WINDOWS_DLL__
#		define WinStuff __declspec(dllexport)
#	endif
#endif

#ifdef __ONIX_SOLARIS__
#	define FuncType
#	define WinStuff
#endif

#ifdef __ONIX_LINUX32__
#	define FuncType
#	define WinStuff
#endif


typedef void * OnixIndexManagerT;
typedef void * OnixIndexingEngineT;
typedef char * OnixFileSpecT;
typedef void * OnixQueryVectorT;
typedef void * OnixResultVectorT;
typedef void * OnixTermCountVectorT;
typedef void * HighlightMatcherT;
typedef void * RobotsTxtParserT;
typedef void * OnixStopWordListT;
typedef void * OnixIndexCreationParamsT;

#ifdef __cplusplus
extern "C" {
#endif


// Create and dispose of the index manager
WinStuff OnixIndexManagerT FuncType ixCreateIndexManager(ULongT Passcode1, ULongT Passcode2, StatusCodeT *Status);
WinStuff void FuncType ixDeleteIndexManager(OnixIndexManagerT IndexManager, StatusCodeT *Status);

// Creating indexes
WinStuff OnixIndexCreationParamsT FuncType ixCreateIndexCreationParams(StatusCodeT *Status);
WinStuff void FuncType ixDeleteIndexCreationParams(OnixIndexCreationParamsT Params);
WinStuff void FuncType ixResetIndexCreationParams(OnixIndexCreationParamsT Params);
WinStuff void FuncType ixSetIndexCreationParams(OnixIndexCreationParamsT Params, int Parameter, void *ParameterValue);
WinStuff void FuncType ixCreateIndex(OnixIndexManagerT IndexManager,OnixFileSpecT File, IndexModeT IndexMode, StatusCodeT *Status);
WinStuff void FuncType ixCreateIndexEx(OnixIndexManagerT IndexManager,OnixIndexCreationParamsT Params, StatusCodeT *Status);

// Get and set the location of temporary files and get their sizes.
WinStuff void FuncType ixSetLocationForTemporaryFiles(OnixFileSpecT PathName);
WinStuff void FuncType ixGetLocationForTemporaryFiles(OnixFileSpecT PathName);
WinStuff void FuncType ixGetTempDiskSpaceUsage(OnixIndexingEngineT Indexer, ULongT *TempFileLength, StatusCodeT *Status);

// Opening and closing indexes.
WinStuff void FuncType ixOpenIndex(OnixIndexManagerT IndexManager, OnixFileSpecT File, StatusCodeT *Status);
WinStuff void FuncType ixCloseIndex(OnixIndexManagerT IndexManager,StatusCodeT *Status);
WinStuff void FuncType ixReloadIndex(OnixIndexManagerT IndexManager,StatusCodeT *Status);

// Routines for indexing
WinStuff void FuncType ixIncrementRecord(OnixIndexingEngineT IndexingEngine, WordTypeT *Word,StatusCodeT *Status);
WinStuff void FuncType ixIndexWord(OnixIndexingEngineT IndexingEngine, WordTypeT *Word, StatusCodeT *Status);
WinStuff void FuncType ixIndexWordSpecial(OnixIndexingEngineT IndexingEngine, WordTypeT *Word, ULongT Flags, ULongT Param, StatusCodeT *Status);
WinStuff void FuncType ixStartField(OnixIndexingEngineT IndexingEngine, UCharT *FieldName, size_t FieldNameLength, StatusCodeT *Status);
WinStuff void FuncType ixEndField(OnixIndexingEngineT IndexingEngine, UCharT *FieldName, size_t FieldNameLength, StatusCodeT *Status);
WinStuff void FuncType ixStemEnglishWord(char *StemmedWord, char *Word);
WinStuff OnixIndexingEngineT FuncType ixStartIndexingSession(OnixIndexManagerT IndexManager, StatusCodeT *Status);
WinStuff void FuncType ixEndIndexingSession(OnixIndexManagerT IndexManager,OnixIndexingEngineT IndexingEngine, WordTypeT *Word, StatusCodeT *Status);
WinStuff void FuncType ixFinalProcessIndex(OnixIndexManagerT IndexManager, OnixIndexingEngineT Indexer, StatusCodeT *Status);
WinStuff void FuncType ixMakeIndexActive(OnixIndexManagerT IndexManager, OnixIndexingEngineT Indexer, StatusCodeT *Status);
WinStuff void FuncType ixSetFinalIndexDataPosition(OnixIndexingEngineT Indexer, OnixFileSpecT FileName, StatusCodeT *Status);

// Additional Routines for performing distributed indexing.
WinStuff OnixIndexingEngineT FuncType ixStartDistributedIndexingSession(OnixIndexCreationParamsT Options, StatusCodeT *Status);
WinStuff void FuncType ixEndDistributedIndexingSession(OnixIndexingEngineT Indexer,StatusCodeT *Status);
WinStuff void FuncType ixAppendDistributedDataToIndex(OnixIndexManagerT IndexManager, OnixFileSpecT FileName, StatusCodeT *Status);


// Routines for storing and retrieving an arbitrary piece of data
// that is associated with every record....
WinStuff void FuncType ixStoreRecordData(OnixIndexingEngineT IndexingEngine, UCharT *DataBuff, size_t RecDataSize, StatusCodeT *Status);
WinStuff void FuncType ixStoreMoreRecordData(OnixIndexingEngineT IndexingEngine, UCharT *DataBuff, size_t RecDataSize, StatusCodeT *Status);
WinStuff void FuncType ixRetrieveRecordData(OnixIndexManagerT IndexManager, UCharT *DataBuff, size_t DataBuffSize, size_t *ReturnedDataSize, RecordNumT RecordNum, OnixDataCursorT *DataCursor, StatusCodeT *Status);
WinStuff void FuncType ixRetrieveMoreRecordData(OnixIndexManagerT IndexManager, UCharT *DataBuff, size_t DataBuffSize, size_t *ReturnedDataSize, OnixDataCursorT *DataCursor, StatusCodeT *Status);

// Functions for managing record IDs.
WinStuff void FuncType ixProcessRecordID(OnixIndexingEngineT IndexingEngine, UCharT *RecordID, size_t RecordIDLength, BooleanT StoreRecordID, BooleanT IndexRecordID, StatusCodeT *Status);
WinStuff void FuncType ixRetrieveRecordID(OnixIndexManagerT IndexManager, UCharT *Buff, size_t BuffSize, size_t *ReturnedIDSize, UCharT *HexRecordID, RecordNumT RecordNum, StatusCodeT *Status);
WinStuff void FuncType ixFindRecordID(OnixIndexManagerT IndexManager, UCharT *RecordIDName, RecordNumT *RecordNum, StatusCodeT *Status);

// Functions to manage the partitions in a multifile index.....
WinStuff void FuncType ixChangePartitionLocation(size_t *PartitionNumber, char *NewPosition, char *OldPosition, StatusCodeT *Status);
WinStuff void FuncType ixWritePartitionLocation(size_t PartitionNumber, char *FileName, StatusCodeT *Status);

// Functions to help give statistics about the index.
WinStuff void FuncType ixNumberOfRecordsInIndex(OnixIndexManagerT IndexManager, RecordNumT *NumRecords, StatusCodeT *Status);
WinStuff void FuncType ixHighestRecordNumberInIndex(OnixIndexManagerT IndexManager, RecordNumT *HighestRecord, StatusCodeT *Status);
WinStuff int  FuncType ixGetNumberOfUnoptomizedInsertions(OnixIndexManagerT IndexManager);

// Routines for managing the deletions of records
WinStuff BooleanT FuncType ixIsRecordDeleted(OnixIndexManagerT IndexManager, RecordNumT RecordNum, StatusCodeT *Status);
WinStuff void FuncType ixDeleteRecordNum(OnixIndexManagerT IndexManager, RecordNumT RecordNum, StatusCodeT *Status);
WinStuff void FuncType ixDeleteRecordNums(OnixIndexManagerT IndexManager, RecordNumT *RecordNumArray, size_t NumRecords, StatusCodeT *Status);
WinStuff void FuncType ixUnDeleteRecordNum(OnixIndexManagerT IndexManager, RecordNumT RecordNum, StatusCodeT *Status);
WinStuff void FuncType ixUnDeleteRecordNums(OnixIndexManagerT IndexManager, RecordNumT *RecordNumArray, size_t NumRecords, StatusCodeT *Status);
WinStuff void FuncType ixOutputDeletedRecords(OnixIndexManagerT IndexManager, RecordNumT *RecordNumArray, StatusCodeT *Status);
WinStuff RecordNumT FuncType ixGetNumberOfRecordsDeleted(OnixIndexManagerT IndexManager, StatusCodeT *Status);

// Routines for the processing of standard queries
WinStuff void FuncType ixStartRetrievalSession(OnixIndexManagerT IndexManager, StatusCodeT *Status);
WinStuff void FuncType ixEndRetrievalSession(OnixIndexManagerT IndexManager, StatusCodeT *Status);
WinStuff void FuncType ixConvertQuery(UCharT *TextQuery, UCharT *HexQuery);
WinStuff void FuncType ixConvertQuery2(UCharT *HexQuery, UCharT *TextQuery);
WinStuff void FuncType ixLongQueryFormToShortQueryForm(UCharT *Query, size_t Proximity);
WinStuff void FuncType ixCharToHex(UCharT C, UCharT *Output);
WinStuff void FuncType ixHexToChar(UCharT *Char, UCharT *Hex);
WinStuff void FuncType ixCharWordToHexWord(UCharT *HexWord, UCharT *CharWord, size_t Length);

WinStuff OnixQueryVectorT
FuncType ixProcessQuery(OnixIndexManagerT IndexManager, UCharT *RankedQueryString, UCharT *QueryString, StatusCodeT *Status);
WinStuff void
FuncType ixNumHits(OnixQueryVectorT Vector, ULongT *NumHits, ULongT *NumRecords, ULongT *NumWords, StatusCodeT *Status);

// Routines for accessing and navigating the wordlist.
WinStuff void FuncType ixFindKey(OnixIndexManagerT IndexManager, DictionaryCursorT *Cursor, UCharT *Word, BooleanT *Found, ULongT *NumRecords, ULongT *NumWords, StatusCodeT *Status);
WinStuff void FuncType ixNextKey(OnixIndexManagerT IndexManager, DictionaryCursorT *Cursor, UCharT *Word, ULongT *NumRecords, ULongT *NumWords, StatusCodeT *Status);
WinStuff void FuncType ixPreviousKey(OnixIndexManagerT IndexManager, DictionaryCursorT *Cursor, UCharT *Word, ULongT *NumRecords, ULongT *NumWords, StatusCodeT *Status);
WinStuff void FuncType ixCurrentKey(OnixIndexManagerT IndexManager, DictionaryCursorT *Cursor, UCharT *Word, ULongT *NumRecords, ULongT *NumWords, StatusCodeT *Status);

// Routines for manually processing queries
WinStuff OnixQueryVectorT FuncType ixCreateResultVector(StatusCodeT *Status);
WinStuff void FuncType ixDeleteResultVector(OnixQueryVectorT Vector, StatusCodeT *Status);
WinStuff OnixQueryVectorT FuncType ixGetCurrentQueryVector(OnixIndexManagerT IndexManager, DictionaryCursorT *Cursor,  StatusCodeT *Status);
WinStuff OnixQueryVectorT FuncType ixVectorAnd(OnixQueryVectorT Vector1, OnixQueryVectorT Vector2, StatusCodeT *Status);
WinStuff OnixQueryVectorT FuncType ixVectorOr(OnixQueryVectorT Vector1, OnixQueryVectorT Vector2, StatusCodeT *Status);
WinStuff OnixQueryVectorT FuncType ixVectorNot(OnixQueryVectorT Vector1, OnixQueryVectorT Vector2, StatusCodeT *Status);
WinStuff void FuncType ixVectorRewind(OnixQueryVectorT Vector, StatusCodeT *Status);
WinStuff void FuncType ixVectorCurrentHit(OnixQueryVectorT Vector, RecordNumT *RecordNum, RecordNumT *WordNum, RecordNumT *CountNum, FloatT *Weight, StatusCodeT *Status);
WinStuff void FuncType ixVectorNextHit(OnixQueryVectorT  Vector, RecordNumT *RecordNum, RecordNumT *WordNum, RecordNumT *Count, FloatT *Weight, StatusCodeT *Status);
WinStuff void FuncType ixVectorNextRecord(OnixQueryVectorT Vector, RecordNumT *RecordNum, WordNumT *WordNum, RecordNumT *Count, FloatT *Weight, StatusCodeT *Status);
WinStuff void FuncType ixVectorPreviousHit(OnixQueryVectorT Vector, RecordNumT *RecordNum, RecordNumT *WordNum, RecordNumT *Count, FloatT *Weight, StatusCodeT *Status);
WinStuff void FuncType ixVectorPreviousRecord(OnixQueryVectorT Vector, RecordNumT *RecordNum, WordNumT *WordNum, RecordNumT *Count, FloatT *Weight, StatusCodeT *Status);
WinStuff OnixTermCountVectorT FuncType ixGetTermCountVector(StatusCodeT *Status);

WinStuff void FuncType ixVectorAddHit(OnixQueryVectorT ResultVector, RecordNumT RecordNum, WordNumT WordNum, FloatT Weight, StatusCodeT *Status);

// Unicode support routines....
WinStuff void FuncType ucInitializeNormalizationTable(UnicodeCharT *TableBuffer, size_t MaxChars, BooleanT	Lower);
WinStuff void FuncType ucTableNormalizeChar(UnicodeCharT *TableBuffer, UnicodeCharT *UnicodeChar, size_t MaxChars);
WinStuff void FuncType ucNormalizeChar(UnicodeCharT *UnicodeChar, BooleanT Lower);
WinStuff void FuncType ixUnicodeCharToHex(UnicodeCharT C, UCharT *Output);
WinStuff void FuncType ixUnicodeHexToChar(UnicodeCharT *Char, UCharT *Hex);

// Routines to assist in highlighting query terms (Supports wildcards */? with escape \)
WinStuff HighlightMatcherT FuncType	ixCreateHighlightMatcher(StatusCodeT *Status);
WinStuff void FuncType ixDeleteHighlightMatcher(HighlightMatcherT HighlightMatcher);
WinStuff void FuncType ixAddWildCardPatternToHighlightMatcher(HighlightMatcherT HighlightMatcher, UCharT *Pattern, size_t PatternLength, StatusCodeT *Status);
WinStuff BooleanT FuncType ixHighlightMatcherMatch(HighlightMatcherT HighlightMatcher, UCharT *Word, size_t WordLength) ;

// Routines to assist web crawlers parse robots.txt
WinStuff RobotsTxtParserT FuncType ixCreateRobotsTxtParser(StatusCodeT *Status);
WinStuff void FuncType ixDeleteRobotsTxtParser(RobotsTxtParserT Parser);
WinStuff void FuncType ixSetRobotName(RobotsTxtParserT Parser, char *Name, size_t CompareLength);
WinStuff void FuncType ixParseRobotsTxt(RobotsTxtParserT Parser, char *RobotsTxt);
WinStuff void FuncType ixOutputCompactRobotsTxt(RobotsTxtParserT Parser, char *RobotsTxt);
WinStuff BooleanT FuncType ixRobotsPermissionGranted(RobotsTxtParserT Parser, char *URL);
WinStuff BooleanT FuncType ixRobotsPermissionGrantedFullURL(RobotsTxtParserT Parser, char *URL);
WinStuff size_t FuncType ixRobotsTxtLength(RobotsTxtParserT Parser);

// Routines for managing the stop word list
WinStuff OnixStopWordListT FuncType ixCreateStopWordList(StatusCodeT *Status);
WinStuff void FuncType ixDeleteStopWordList(OnixStopWordListT StopWordList);
WinStuff void FuncType ixAddStopWord(OnixStopWordListT StopWordList, UCharT *Word, size_t WordLength, StatusCodeT *Status);
WinStuff void FuncType ixAddStopWordList(OnixStopWordListT StopWordList, char *FileName, StatusCodeT *Status);
WinStuff BooleanT FuncType ixIsStopWord(OnixStopWordListT StopWordList, size_t PrefixLength, UCharT *Word, size_t WordLength);
WinStuff size_t FuncType ixNumStopWords(OnixStopWordListT StopWordList);

// Routines to manage the stats file(s)
WinStuff void FuncType ixOutputStatsFile(OnixIndexManagerT IndexManager,OnixFileSpecT FileName,StatusCodeT *Status);

// Used to get the current status message text string (Errors, UnErrors, etc.)
//void FuncType GetStatusMessage(StatusCodeT Status, char *StatusMessageBuff);
WinStuff char * FuncType ixGetStatusMessage(StatusCodeT *Status, char *StatusMessageBuff, size_t BuffLength);

#ifdef __cplusplus
} // end extern "C"
#endif

#endif
