#ifndef __ONIX_TYPES__
#define __ONIX_TYPES__

#include <stdlib.h>

#define MAXWORDSIZE                     (255)
#define MAXWORDBUFFERSIZE               (MAXWORDSIZE +1)

#ifdef __MACINTOSH__
#include <limits.h>
#ifndef MAXINT
#define MAXINT LONG_MAX
#endif
#ifndef MAXUINT
#define MAXUINT ULONG_MAX
#endif
#endif

// Indexing modes                  
//#define RECORD_MODE             (1)
//#define WORD_MODE               (2)
//#define IDF_MODE                (3)

typedef enum {
	RecordMode 	= 1,
	WordMode		= 2,
	IDFMode		= 3,
   MaxMode    	= 0xFFFFFFFF
} IndexModeT;

typedef unsigned char 	UCharT;
typedef unsigned long 	ULongT;
typedef unsigned short 	UShortT;
typedef float				FloatT;
typedef long				LongT;
typedef unsigned long	RecordNumT;
typedef unsigned long	WordNumT;
typedef unsigned short 	UnicodeCharT;


// Flags for creating indexes
#define SINGLEPOINT_INDEX					0x00000001L
#define DISTRIBUTED_INDEX					0x00000002L
#define VARIABLE_LENGTH_RECINFO			0x00000004L
#define FIXED_LENGTH_RECINFO				0x00000008L
#define RECINFO_32_BIT_OFFSET				0x00000010L
#define RECINFO_64_BIT_OFFSET				0x00000020L
#define VARIABLE_LENGTH_RECORD_ID		0x00000040L
#define FIXED_LENGTH_RECORD_ID			0x00000080L
#define RECID_32_BIT_OFFSET				0x00000100L
#define RECID_64_BIT_OFFSET				0x00000200L
#define RANKING_METHOD_ONE					0x00000400L
#define RANKING_METHOD_TWO					0x00000800L


const long ixSetSinglePointIndex	 			= 1;
const long ixSetDistributedIndex	 			= 2;
const long ixSetVariableLengthRecordInfo 	= 3;
const long ixSetFixedLengthRecordInfo 		= 4;
const long ixSet32BitRecordInfoOffset 		= 5;
const long ixSet64BitRecordInfoOffset 		= 6;
const long ixSetFixedLengthRecordID			= 7;
const long ixSetVariableLengthRecordID 	= 8;
const long ixSetRecordID32BitOffset 		= 9;
const long ixSetRecordID64BitOffset 		= 10;
const long ixSetIndexMode 						= 11;
const long ixSetIndexFileName					= 12;
const long ixSetRankingMethodOne				= 13;
const long ixSetRankingMethodTwo				= 14;


// Flags for optomizing the index
#define OPTFLAG_DELETE_OLD_PARTITIONS		0x00000001L
#define OPTFLAG_REMOVE_EMPTY_RECORD_NUMS	0x00000002L


// Flags for indexing words
#define IX_IGNORE_ENTRY    			0x00000001L
#define IX_SAME_AS_LAST_ENTRY       0x00000002L


//#if __BCPLUSPLUS__ == 0x520

typedef long StatusCodeT;

const long			AllDataOptomizedAway 	= 	6; // After running the optomizer, there is no data left
const	long 			Done							= 	5;	// We are done with whatever we are doing
const	long 			Full							=  4; // Whatever you have been working with is full.
const	long 			Found							=  3; // What you were looking for has been found.
const	long 			NotFound						=  2; // What you were looking for was not found.
const	long 			EndOfHitList				=  1;	// We are at the end of the query vector
const	long 			eNoError  	      		=  0; // NoError;
const	long 			eNoMemory         		= -1; // Not enough memory
const	long 			eReadOnly         		= -2; // File is read only
const	long 			eReading          		= -3; // Error reading from file
const	long 			eWriting          		= -4; // Error writing to file
const	long 			eSeeking          		= -5; // We were not able to seek where we wanted
const	long 			eFileNotFound     		= -6; // Not able to find the file
const	long 			eNoDrive          		= -7; // No such drive
const	long 			eAccess           		= -8; // File is locked by another process
const	long 			eFileExists       		= -9; // File already exists
const	long 			eCantDeleteFile   		= -10;// For some reason the file can't be deleted
const	long 			eOpeningFile				= -11;// Can't open the file specified
const	long 			eClosingFile				= -12;// Can't close the file specified
const	long 			eMagicNumberMismatch 	= -13;// File is not index file or is corrupt
const	long 			eIndexLocked       		= -14;// Index is locked by another process
const	long 			eNoCurrentKey		 		= -15;// No current key (Need to find a key first.)
const	long 			eEndOfWordList		 		= -16;// End of the wordlist
const	long 			eIndexNotLoaded	 		= -17;// The index isn't loaded
const	long 			eNoCurrentHit		 		= -19;// There isn't a current hit.  (Probably no hits were returned.)
const	long 			eMalformedParameter 		= -20;// The parameter in the expression
const	long 			eMalformedExpression 	= -21;// Something is wrong with the query expression
const	long 			eMismatchedQuotes			= -22;// There are mismatched quotes in the query expression
const	long 			eMismatchedParens 		= -23;// There are mismatched parens () in the
const	long 			eLeftParenExpected 		= -24;// There is a extra right paren in the query expression
const	long 			eRightParenExpected 		= -25;// There is an extra left paren in the query expression
const	long 			eTermExpectedInRange 	= -26;// You need a term on both sides of a range (i.e., X - Y)
const	long 			eLeftAngleBracketExpected 			= -27; // A left angle bracket \"<\" is expected in the query expression.  Check the usage of the angle brackets within the query expression.
const	long 			eRightAngleBracketExpected 		= -28; // A right angle bracket \">\" is expected in the query expression.  Check the usage of the angle brackets within the query expression.
const	long 			eCantHaveOperatorsInsideQuotes 	= -29; // The only operators allowed inside a quote are: Or, Left Parentheses and Right Parentheses -- |,(,)")
const	long 			eRightHandQuoteExpected 			= -30; // Missing a right hand quote in the query expression
const	long 			eMalformedQueryTerm 					= -31; // The Query Term must be a hex number i.e, 0xffaa
const	long 			eNoDataInIndex							= -32; // We have an empty index
const	long 			eNoRetrievalSession					= -33; // We need to start a retrieval session before querying the index
const	long 			eNoIndexSession						= -34; // We need to start an index session before starting to index.
const	long 			eCompressionError						= -35; // General compression error. (i.e., didn't start or end correctly
const	long 			eNumberOutOfRange						= -36; // The value specified is not in a range it should be in
const	long 			eGeneralError      					= -37; // Beats me what the error is
const long			eNoDataStoredInIndex					= -38; // There was a request for record data but none was present in the index.
const long			eLibraryTimedOut						= -39; // This library has timed out.  Contact Art Pollard (pollarda@lextek.com) to get details.
const long			eIndexIsOnRemoveableDisk			= -40; // Your license doesn't allow for the index to be on a removeable disk.
const long			eMaxDataIndexed						= -41; // Your license doesn't allow for more data to be indexed.  (Too much data indexed for license.)
const long			eInvalidPasscode						= -42; // An invalid license passcode was entered.  Recheck passcode or contact Lextek International (http://www.lextek.com) for a valid passcode.
const long        eHitNotFound                     = -43; // The hit searched for is not in this query vector
const long			eDeletingFile							= -44; // Sorry, can't delete the file.
const long			eInvalidKeyLength						= -45; // The key length does not conform to the specifications.  (Probably too long)
const long			ePartitionNotFound					= -46; // The index partition specified was not found.


// Make everything single byte aligned if using the MS compiler.
#ifdef __ONIX_MICROSOFT__
#pragma pack(push,1)
#endif

typedef struct {
		  UCharT Word[MAXWORDBUFFERSIZE];
		  UCharT Length;
		  UCharT TermType;		// Reserved for future use
		  ULongT FileNumber;		// Reserved for future use
		  ULongT RecordNumber; 	// Reserved for future use
		  ULongT RecordOffset; 	// Reserved for future use
		  ULongT LastWordNumber;// Reserved for future use
} WordTypeT;


#ifndef __BOOLEANT__
#define __BOOLEANT__
typedef enum {
		BooleanTrue 	= 1,
		BooleanFalse 	= 0
} BooleanT;
#endif

typedef struct {
	BooleanT HasCurrentWord;
	UCharT 	Word[MAXWORDBUFFERSIZE];
	ULongT 	NumberOfRecords;
	ULongT 	NumberOfWords;
} DictionaryCursorT;

typedef struct {
	size_t		N;
	RecordNumT	RecordNumber;
	ULongT		DataOffset;
   ULongT		DataLength;
   ULongT		CurrentPos;
   BooleanT		Done;
} OnixDataCursorT;


// Set all the packing back to the normal setting for the 
// Microsoft compiler.
#ifdef __ONIX_MICROSOFT__
#pragma pack(pop)
#endif

#endif